@@ -54,6 +54,8 @@ from mezcla import system
 RANDOM_SEED = tpo.getenv_integer("RANDOM_SEED", 15485863,
                                  "Integral seed for random number generation (n.b., use ' ' for default [time of day based])")
 
+## TEMP:
+## pylint: disable=consider-using-f-string
 
 class Dummy_Main(Main):
     """Class for reading input using Main"""
@@ -77,9 +79,12 @@ def main():
         sys.exit()
 
     # Check command-line arguments
-    parser = argparse.ArgumentParser(description="Randomize lines in a file (without reading entirely into memory).")
+    global RANDOM_SEED
+    ## OLD: parser = argparse.ArgumentParser(description="Randomize lines in a file (without reading entirely into memory).")
+    parser = argparse.ArgumentParser(description=f"Randomize lines in a file (without reading entirely into memory).The default seed is {RANDOM_SEED}.")
     parser.add_argument("--include-header", default=False, action='store_true', help="Keep first line as headers")
-    parser.add_argument("--seed", type=int, default=None, help="random seed (e.g., 122949823, the seven-millionth prime)")
+    ## OLD: parser.add_argument("--seed", type=int, default=None, help="random seed (e.g., 122949823, the seven-millionth prime)")
+    parser.add_argument("--seed", type=int, default=RANDOM_SEED, help="random seed (e.g., 122949823, the seven-millionth prime)")
     parser.add_argument("filename", nargs='?', default='-', help="Input filename")
     args = vars(parser.parse_args())
     tpo.debug_print("args = %s" % args, 5)
@@ -94,8 +99,12 @@ def main():
         ## TODO: figure out proper way to re-open stdin
         STDIN = 0
         input_stream = system.open_file(STDIN)
-    global RANDOM_SEED
-    if args['seed']:
+    ## TODO: cleanup RANDOM_SEED access
+    ## OLD:
+    ## global RANDOM_SEED
+    ## if args['seed']:
+    debug.assertion(args['seed'])
+    if (args['seed'] is not None):
         RANDOM_SEED = int(args['seed'])
     include_header = args['include_header']
 
@@ -107,7 +116,8 @@ def main():
     temp_base = tpo.getenv_text("TEMP_FILE", gh.get_temp_file())
     temp_input_file = temp_base + ".input"
     temp_output_file = temp_base + ".output"
-    temp_input_handle = open(temp_input_file, "w")
+    ## OLD: temp_input_handle = open(temp_input_file, "w")
+    temp_input_handle = system.open_file(temp_input_file, mode="w")
     assert(temp_input_handle)
     #
     header = None
@@ -142,7 +152,8 @@ def main():
 
     # Display result
     # TODO: send output of command above to stdout
-    temp_output_handle = open(temp_output_file, "r")
+    ## OLD: temp_output_handle = open(temp_output_file, "r")
+    temp_output_handle = system.open_file(temp_output_file, mode="r")
     assert(temp_output_handle)
     line_num = 0
     IO_error = False
